@@ -5,18 +5,20 @@ use mro 'c3';
 extends 'Catalyst::Model';
 with 'CatalystX::Component::Traits';
 
-our $VERSION = '0.59';
-$VERSION = eval $VERSION;
+our $VERSION = '0.66';
+$VERSION =~ tr/_//d;
 
 use namespace::autoclean;
 use Carp::Clan '^Catalyst::Model::DBIC::Schema';
 use Data::Dumper;
 use DBIx::Class ();
+use Module::Runtime qw/use_module/;
 
 use Catalyst::Model::DBIC::Schema::Types
-    qw/ConnectInfo LoadedClass SchemaClass Schema/;
+    qw/ConnectInfo SchemaClass Schema/;
 
-use MooseX::Types::Moose qw/ArrayRef Str ClassName Undef/;
+use MooseX::Types::Moose qw/Str Bool/;
+use MooseX::Types::LoadableClass qw/LoadableClass/;
 
 =head1 NAME
 
@@ -304,6 +306,17 @@ Traits that come with the distribution:
 
 =back
 
+=head2 compose_namespaces
+
+This model calls L<DBIx::Class::Schema/compose_namespace> by default to
+install classes into the model namespaces. You can turn that off by
+setting this attribute to false. Default is true.
+
+=head2 install_model_shortcuts
+
+If you don't want shortcut models so you can do e.g. C<< $c->model('DB::Book')
+>> set this attribute to false, Default is true.
+
 =head2 storage_type
 
 Allows the use of a different C<storage_type> than what is set in your
@@ -374,10 +387,13 @@ schema->resultset, schema->source, and schema->class.
 =head2 composed_schema
 
 Accessor which returns the composed schema, which has no connection info,
-which was used in constructing the C<schema> above.  Useful for creating
+which was used in constructing the L</schema>. Useful for creating
 new connections based on the same schema/model.  There are direct shortcuts
 from the model object for composed_schema->clone and composed_schema->connect
 
+If L</compose_namespaces> is not true, L</composed_schema> is equivalent to
+C<< $model->schema_class->clone >>.
+
 =head2 clone
 
 Shortcut for ->composed_schema->clone
@@ -417,10 +433,13 @@ See L<DBIx::Class::Storage> and L<DBIx::Class::Storage::DBI>.
 has schema_class => (
     is => 'ro',
     isa => SchemaClass,
-    coerce => 1,
     required => 1
 );
 
+has compose_namespaces => (is => 'ro', isa => Bool, default => 1 );
+
+has install_model_shortcuts => (is => 'ro', isa => Bool, default => 1 );
+
 has storage_type => (is => 'rw', isa => Str);
 
 has connect_info => (is => 'rw', isa => ConnectInfo, coerce => 1);
@@ -434,9 +453,8 @@ has model_name => (
 
 has _default_cursor_class => (
     is => 'ro',
-    isa => LoadedClass,
+    isa => LoadableClass,
     default => 'DBIx::Class::Storage::DBI::Cursor',
-    coerce => 1
 );
 
 has schema => (is => 'rw', isa => Schema);
@@ -467,7 +485,7 @@ sub BUILD {
     }
 
     if (exists $self->connect_info->{cursor_class}) {
-        eval { Class::MOP::load_class($self->connect_info->{cursor_class}) }
+        eval { use_module($self->connect_info->{cursor_class}) }
             or croak "invalid connect_info: Cannot load your cursor_class"
         . " ".$self->connect_info->{cursor_class}.": $@";
     }
@@ -476,8 +494,13 @@ sub BUILD {
 
     my $is_installed = defined $self->composed_schema;
 
-    $self->composed_schema($schema_class->compose_namespace($class))
-        unless $is_installed;
+    if (not $is_installed) {
+        $self->composed_schema($self->compose_namespaces ?
+            $schema_class->compose_namespace($class)
+            :
+            $schema_class->clone
+        );
+    }
 
     $self->schema($self->composed_schema->clone)
         unless $self->schema;
@@ -487,7 +510,9 @@ sub BUILD {
 
     $self->schema->connection($self->connect_info);
 
-    $self->_install_rs_models unless $is_installed;
+    if ((not $is_installed) && $self->install_model_shortcuts) {
+        $self->_install_rs_models;
+    }
 }
 
 sub clone { shift->composed_schema->clone(@_); }
@@ -676,7 +701,7 @@ ozum: Ozum Eldogan C<ozum@ozum.net>
 
 Pavel I. Shaydo C<zwon@trinitum.org>
 
-t0m: Tomas Doran <bobtfish@bobtfish.net>
+SineSwiper: Brendan Byrd <byrd.b@insightcom.com>
 
 =head1 COPYRIGHT
 
